@@ -1,11 +1,16 @@
 
-Epan<-function(x) { return(((3/4)*(1-(x)^2))*(abs(x)<1))}
-
 K_b <- function(b,x,y, K){
   K_h = (1/b)*K((x-y)/b)
   return(K_h)
 }
 
+
+xK_b  <- function(b,x,y, K){
+  K_h = (1/b)*K((x-y)/b)*  (x-y) 
+  return(K_h)
+}
+ 
+
 K_b_mat <- function(b,x,y, K){
   x_mat = replicate(length(x), x)
   y_mat = t(replicate(length(y), y))
@@ -13,3 +18,7 @@ K_b_mat <- function(b,x,y, K){
   return(K_h)
 }
 
+ 
+
+
+
